@@ -11,8 +11,10 @@ use Carp;
 sub ACTION_authortest {
     my ( $self, @args ) = @_;
 
+    local $ENV{AUTHOR_TESTING} = 1;
+
     $self->depends_on( 'build' );
-    $self->test_files( qw{ t xt } );
+    $self->test_files( qw{ t xt/author } );
     $self->depends_on( 'test' );
 
     return;
@@ -75,7 +77,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2010, Thomas R. Wyant, III
+Copyright (C) 2009-2011, 2013-2014 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
